+++
title = "Multi-line footnote Japanese"
tags = ["footnote"]
draft = false
+++

Here is a footnote where it originally had Japanese text on both
lines[^fn:1].

Here is a footnote where originally the first line ended in English
but next line started with Japanese[^fn:2].

Here is a footnote entirely in English[^fn:3].

[^fn:1]: これはテストです.
[^fn:2]: English on line 1 の Japanese on line 2
[^fn:3]: This is a long footnote. It is so long that it gets auto-filled over multiple lines. But even then it should be handled fine.
